##  Introduction
Zscaler is a cloud-based security platform that protects corporate networks and internet access through services like web security, firewall protection, data loss prevention, and secure web gateway functionality.
Once the Zscaler integration is configured, SAP LeanIX uses Zscaler to discover the SaaS applications used within your organization. SAP LeanIX uses Zscaler's ZIA API to discover SaaS applications. To set up this integration, you must provide Zscaler credentials with the appropriate permissions.
**Note**
If you intend to manually review and link each discovered application to fact sheets, deactivate automatic linking in the SaaS discovery inbox settings before configuring the integration. For details, see [Automatic Linking of Discovered Applications to Fact Sheets](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c41a87a441014aa86ff57b7a5198f__automatic_linking).
